;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x0adbb0515632fb9f34b1e2552e2a53a4 . "./code.cg2js/cg-common-control.fasl")
(#x4b8481486b55fd44b9beb204b1100aa7 . "./code.cg2js/cg-header-control.fasl")
(#x38664cb3013ed673771045fb6dcfce49 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xf9c9b9579f67a7d582129015d8e7762b . "./code.cg2js/cg-yes-no-string.fasl")
(#xfae9ab94c5b3f1e3f17ef2d8e6f71c78 . "./code.cg2js/cg-clipboard.fasl")
(#xe1dc0f2c69861d1934f8772a5065b5b9 . "./code.cg2js/cg-dde-utils.fasl")
(#x0160ef9ad59278589767e3949b84ace5 . "./code.cg2js/cg-editable-text.fasl")
(#xde80a9428ba0390f20da1db0cbf7c7a1 . "./code.cg2js/cg-text-or-combo.fasl")
(#x9af1066bf552f9a61418a9e495df8174 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x6fc8e8c3bfbbbe6c0dd76542185d9c56 . "./code.cg2js/cg-graphics-context.fasl")
(#x04e198823794090e6a79b10cf6e76cab . "./code.cg2js/cg-choose-printer.fasl")
(#x0b778aa562f15ce3b6a7a7e296fd88e2 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xfe39a30ef0395538fa9dc95d581bd4a7 . "./code.cg2js/cg-edit-in-place.fasl")
(#xc61aa2764a4a0a7f383778326e8d9c24 . "./code.cg2js/cg-split-bar.fasl")
(#x0e651dba70fe5f55d158f3b64f0371e9 . "./code.cg2js/cg-timer.fasl")
(#x59e5e9a6f0d3d91d248a9517bb3ca310 . "./code.cg2js/cg-progress-indicator.fasl")
(#x9a1054516019b8e4ee78754763e03e86 . "./code.cg2js/cg-object-editor.fasl")
(#x0b5653b452ab319d17c40b2b59d96513 . "./code.cg2js/cg-fill-texture.fasl")
(#xafb7d3b032088f3daee0d937e3465bd4 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xd92b435b3cd526053e8a1e311c00a251 . "./code.cg2js/cg-os-window.fasl")
(#xef9c7051fc4e6004868e3f54ee044d0c . "./code.cg2js/cg-color-dialog.fasl")
(#xa1aba4c1eaa11046115bbc31e08d975c . "./code.cg2js/cg-combo-box.fasl")
(#xe4f3a8a6a9d8ac0f3fd01f99ae36eb31 . "./code.cg2js/cg-directory-dialog.fasl")
(#xab0ad704d2db8cf73eb94f130fc3f83d . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x9a5374b44510e449575ac152994ec758 . "./code.cg2js/cg-tooltip.fasl")
(#x71416c6c3443592bf0375f505bab30ec . "./code.cg2js/cg-lettered-menu.fasl")
(#x105c97a50f5413b8feeec8926227c433 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xfc37b6d340f2ee0a4c5f2b912f718fe0 . "./code.cg2js/cg-pixmap.fasl")
(#x1814df19700c7dcc498206039e1775b3 . "./code.cg2js/cg.fasl")
(#xf595964a9caf4301da12f96153146c81 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xfcc274b94144bc39a6e37f177b71b1d4 . "./code.cg2js/cg-template-string.fasl")
(#x916e688db650e204ef5a0668689f25b5 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x29fc2fa5c7a5fba7c89a7a695a73d002 . "./code.cg2js/cg-check-box.fasl")
(#x32e6d32ba00edb11ad431035552e142d . "./code.cg2js/cg-toggling-widget.fasl")
(#xcb8b77eb0686e70ab1115f6aa544a78f . "./code.cg2js/cg-radio-button.fasl")
(#xf5fd5b31cf1490d25292e741e69ae6a2 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x1f3fbec978668393701f297c797275ad . "./code.cg2js/cg-scaling-stream.fasl")
(#xd2749677d391ea89d620ff8424181d91 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xea99c605591be24d3241ac6d2d46be4b . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x6e2b66b0884c58413ebfb66369c6df21 . "./code.cg2js/cg-grid-widget.fasl")
(#xc643b804db5c99c2aa6a455d54d9490d . "./code.cg2js/cg-text-edit-pane.fasl")
(#x52c285165e05f32dd3e652f4f8dfb805 . "./code.cg2js/cg-item-list.fasl")
(#xd742f040fa30beb69b7cb746f1d6bf5f . "./code.cg2js/cg-paren-matching.fasl")
(#xca39bfab972b4b9d893387ee2810c748 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x01e06d977937f46e86e08170c0d43f38 . "./code.cg2js/cg-html-dialog.fasl")
(#xb0326f6f72fb92ac5fb5da21464e23a9 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xf021d762dbf976356f3a73920006fcec . "./code.cg2js/cg-project-window.fasl")
(#xe61cd459f64fd7efb9a5e31f6defa08e . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xf7c569bca5f9e65e7a4742dd304a3de2 . "./code.cg2js/cg-toolbar.fasl")
(#x25b846129570a3e01e598257a3e6da03 . "./code.cg2js/cg-caret.fasl")
(#x915edac38694b50b07a1f70392b95a5b . "./code.cg2js/cg-scroll-bar.fasl")
(#xb4115b578074f35329631b2c5a92e2de . "./code.cg2js/cg-web-browser.fasl")
(#xe69a001aa3dfc4040a2ea80168e461fc . "./code.cg2js/cg-dropping-outline.fasl")
(#x59acbb25a68031e49a9ea67b1e992252 . "./code.cg2js/cg-font-dialog.fasl")
(#x335669b6c33153bdc52b9bed134a93f0 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xd94bb0095ed68c5c00eff0969fcb0443 . "./code.cg2js/cg-yes-no-list.fasl")
(#xf5863c6c622e4d4851bd6ef404bc6c16 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x31d9c0c13bc43048a309a6bf2c62de2a . "./code.cg2js/cg-lamp.fasl")
(#x5a3dc931bdb3b93b33130863da11dd2e . "./code.cg2js/cg-drawable.fasl")
(#x4dc6b34403b2230d3e107e2186089571 . "./code.cg2js/cg-choice-list.fasl")
(#x68c0685c03ab5f6f9145b4f0f2785183 . "./code.cg2js/cg-curve.fasl")
(#xa3e8a36b19550535f8480d0199361b7d . "./code.cg2js/cg-base.fasl")
(#xe1cd7e30644666c341c66aeb1fc2b3ed . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x28a855f453e1aa5adf344e5a3a0784e8 . "./code.cg2js/cg-printing.fasl")
(#xf1bc0d8b1438cc736aa678d918399c91 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x20cf6a04efb031b189c86f70a48d80e4 . "./code.cg2js/cg-hotspot.fasl")
(#x7323265b379698d5996165719ad51d74 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x74bc31abd63f005f93aa537a0c1d4f31 . "./code.cg2js/cg-utility-dialog.fasl")
(#x57774f7b8cd5a07090b7440feb211b5e . "./code.cg2js/cg-shortcut-menu.fasl")
(#xa096566f8e5b3b5b63a68c525990eb02 . "./code.cg2js/cg-comtab.fasl")
(#x5d45f477a2226641b6d603292ca70704 . "./code.cg2js/cg-os-widget.fasl")
(#xfef7092c22e59edd766f129e48e6da47 . "./code.cg2js/cg-icon.fasl")
(#x356be7142fffec74337f141587419962 . "./code.cg2js/cg-dev.fasl")
(#xc161741201c850d0c01ce3a7cf8dc692 . "./code.cg2js/cg-calendar.fasl")
(#xc4e8f343fefda33d6e5ea3fac7f2c98c . "./code.cg2js/cg-group-box.fasl")
(#x4ac234b00a15e8ccf6f9ebd14fc7f540 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xfa6329c1ae26bcb22e4ad3cde686b5b0 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xa12969bdd98a4302093b6dd7f63ec762 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x97b9688641f4adb1ed47a0f37649aa5b . "./code.cg2js/cg-nodes.fasl")
(#xb505238d16a4b5bb99c9e151603364ec . "./code.cg2js/cg-intersect.fasl")
(#xdd01e539464a40d37b79928de7933121 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x19ffd76e1ceea00a6d7c59476c706b05 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x6addc05d3a4f58ecb88be81e9a6b9035 . "./code.cg2js/cg-class-support.fasl")
(#x76f12bcc65f562152694288ed83da9ec . "./code.cg2js/cg-dialog-item.fasl")
(#x3c3e46aa6b7210ee19bc31e217514ac9 . "./code.cg2js/cg-plot-widget.fasl")
(#xd8dc35cf03f627b9443bc71a0d5769e7 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xb6675b46c1d35325bd9331d8738ff95d . "./code.cg2js/cg-up-down-control.fasl")
(#x90823eb1eef6015bc00198b028a8dd77 . "./code.cg2js/cg-rich-edit.fasl")
(#x18bcfb241188ab32b3e54b2323680f9d . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x34320c16f4c6896a789413cdb6729e5e . "./code.cg2js/cg-status-bar.fasl")
(#xf03687e20867a6c75d950cd2357fd1c3 . "./code.cg2js/cg-class-grid.fasl")
(#x1c59b6c5b1e856de5b2510623b5b97c6 . "./code.cg2js/cg-wrap-string.fasl")
(#x7c8b6175c5291b4373913bbc58d1b634 . "./code.cg2js/cg-layout.fasl")
(#x2bf576f23973106b82601b231fe07daf . "./code.cg2js/cg-lisp-widget.fasl")
(#xa241b417f48978aec577b23ab7a16b9b . "./code.cg2js/cg-button.fasl")
(#xcbc35f685da6f3fa0c879e96f1438719 . "./code.cg2js/cg-string-dialog.fasl")
(#x491589ebccec548d63062e9aa4546168 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x012913f28870c11f06b1c7a9df847667 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x5c33b44f565c3b80e96b64b913a85fa7 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x0ab903408d7ae64fc2761e44c0ff9b74 . "./code.cg2js/cg-static-text.fasl")
(#xca6af70c2c5007366cd64d765136cf6b . "./code.cg2js/cg-outline.fasl")
(#xe3d0ddc3f2deea0fd46198c58340d3b1 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xef0ead2c6b5e22255839d0cfdf61ba9b . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xef28fcb2f9464f0e76a33ae806dd5633 . "./code.cg2js/cg-picture-widget.fasl")
(#x1a2ba563e5a1fc425cd0f230330fe94f . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xdcb853fa1db06507b303b556221173e5 . "./code.cg2js/cg-chart-widget.fasl")
(#x51038f71b687bd5572c372f27b936fc1 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x8393b55466110c6373c0d749250ebc8e . "./code.cg2js/cg-lisp-text.fasl")
(#x83011b92c07264219608cad25634bc10 . "./code.cg2js/cg-palette.fasl")
(#xbffeb3ed8c88a340ef5f723880f7dcbb . "./code.cg2js/cg-property.fasl")
(#xfa84602e7a0785a209ac0dc6cfbac5ee . "./code.cg2js/cg-intersect-posbox.fasl")
(#xe8093b6c94ff8769f4af725bc717094e . "./code.cg2js/cg-file-dialog.fasl")
(#x3e074fb98c75239393d8d461674823d4 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x18b37e72dc5090de325b9284c270be4e . "./code.cg2js/cg-get-pixmap.fasl")
(#x0d416c8f2fbae7665c80be8aed1286c6 . "./code.cg2js/cg-tray.fasl")
(#xb2128f3a4c9f376010d5fd6c97235e6a . "./code.cg2js/cg-acache.fasl")
(#xf14d7ddd23662a2510eec70976641e0a . "./code.cg2js/cg-message-dialog.fasl")
(#x11658461036f37f41a90449f3d6de21b . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x04a186e1d68eb1c496465d0f5ced2503 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x050b0c489abbdf01e44a8365e2e80595 . "./code.cg2js/cg-tab-control.fasl")
(#xd620457fea44a6ee4d15e27e8b6a6100 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xd112f104120b6df26f04ca7d8d70ea53 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x0f29cd3780da167c4ecfc3c84269c217 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xbf486da23ba9077ef795e4d4d5913c53 . "./code.cg2js/cg-menu.fasl")
(#xf0828c4c325696947e2444c568a97625 . "./code.cg2js/cg-get-position.fasl")
(#xdae81f39e7e6a03bd15908bdfa9241fc . "./code.cg2js/cg-trackbar.fasl")
(#x53b93626341c8db4ff4731e96b916803 . "./code.cg2js/cg-selected-object.fasl")
(#x7b6b758bb767c60465fba444120599ee . "./code.cg2js/cg-list-view.fasl")
(#xd0c49447da31f41a090f702074551950 . "./code.cg2js/cg-html-widget.fasl")
(#xedd5ffc3b9ae584dcd7a6ae707cea725 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x547f52031ff0bd7613bf21cfc6affe71 . "./code.cg2js/cg-text-widget.fasl")
(#x39bcc226d36c4b67cf1bd880039d511c . "./code.idejs/ide-base.fasl")
(#xd6da417f3960bdfbe22465c706312459 . "./code.idejs/ide-process-browser.fasl")
(#xa6e7166f03e8b64e50d590cbaa754629 . "./code.idejs/ide-patch-dialog.fasl")
(#x20d2e3f1d7f1e2ff6c7301a003db22d8 . "./code.idejs/ide-keyshort.fasl")
(#x123967e1bc83ae280e2e6a39ed67566c . "./code.idejs/ide-window-list.fasl")
(#x929c4c35b55d372df15e36e5aea2f01a . "./code.idejs/ide.fasl")
(#x46b07e6f4a0c167b2ef145097c506a3e . "./code.idejs/ide-editor.fasl")
(#x7ee62e8673acd4931f70716c5bc91a7d . "./code.idejs/ide-clipboard.fasl")
(#x2fc5463ef64fed4dd89b216d7b0b8072 . "./code.idejs/ide-trace.fasl")
(#x62088248f39ddb342801389073fc48d4 . "./code.idejs/ide-class-browser.fasl")
(#x6db3261c1e5b6eb4f961528c16822c2f . "./code.idejs/ide-grapher.fasl")
(#xcd3ce9937af3ea9c0e673b3cca0219e3 . "./code.idejs/ide-apropos.fasl")
(#x234119f509487a59af1d96a3594e4d03 . "./code.idejs/ide-navigator.fasl")
(#xb27620e15dcf7245cfd1688bc3011adb . "./code.idejs/ide-find-definitions.fasl")
(#x7c500c4998eb0c91254309f2a7727f86 . "./code.idejs/ide-project.fasl")
(#xde08d4a09b547bab946d6aef00c26796 . "./code.idejs/ide-class-grapher.fasl")
(#xcf2db0be49ee6168d40db2aa6702e42a . "./code.idejs/ide-acache.fasl")
(#x4fd7d862093d6f43f0cf94aa9303e419 . "./code.idejs/ide-find-in-files.fasl")
(#x248d15d6414f791e9bff9e7259680c3c . "./code.idejs/ide-inspector.fasl")
(#x78efcb601c7770786f7fea2a50684380 . "./code.idejs/ide-intro.fasl")
(#x1a34cb9d8a3bba304a8b688ed9c87111 . "./code.idejs/ide-package-list.fasl")
(#xdeac187f94e8e9ebc7aa7704f1f3101a . "./code.idejs/ide-dev.fasl")
(#x77ce83e005dee85c7dbce4bf3063255c . "./code.idejs/ide-form.fasl")
(#xb19a66ec109be5a69fb5293c577fc104 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
